/************************************************************************
 *                  FileConverter JAVA CSV2Coords v2.0                  *
 ************************************************************************
 * Copyright (C) 2005-07 by Michael Loesler, http://derletztekick.com   *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/
 
import java.util.*;
import java.io.File;

public class CSV2Coords extends Toolbox {
  private File fileName;
  private Vector<Point23> points = null;
  
  private String Seperator = null;
  private int pktrow, coderow, xrow, yrow, zrow;
  public CSV2Coords () { }
  
  public CSV2Coords(File f){
    this(f, "," ,0,1,2,3,4);
  }

  public CSV2Coords(File f, String Seperator){
    this(f, Seperator,0,1,2,3,4);
  }
  
  public CSV2Coords(File f, int pktrow, int coderow, int yrow, int xrow, int zrow){
    this(f, "," ,pktrow, coderow, yrow, xrow, zrow);
  }
  
  public CSV2Coords(File f, String Seperator, int pktrow, int coderow, int yrow, int xrow, int zrow){
    if (f.exists() && f.isFile() && f.canRead() && f.toString().toLowerCase().endsWith( ".csv" )){
      this.fileName = f;
      this.Seperator = Seperator.trim().equalsIgnoreCase("")?"\\s+":Seperator;
      this.points = new Vector<Point23>();
      this.pktrow = pktrow;
      this.coderow = coderow;
      this.yrow = yrow;
      this.xrow = xrow;
      this.zrow = zrow;
      if (!this.getCoords() || this.points.size() < 1)
        this.points = null;
    }
  }
  
  public Vector getPoints(){
    return this.points;
  }

  private boolean getCoords(){
    if (this.fileName == null)
      return false;

    Vector<String> v = this.readSourcefile( this.fileName );
    if (v == null)
      return false;

    for (int i=0; i<v.size(); i++){
      Point23 p23 = new Point23();
      String splitedString[] = v.get(i).split(this.Seperator);

      if (this.pktrow != -1 && splitedString.length-1 >= this.pktrow ){
        p23.setPKT(splitedString[this.pktrow].trim());
      }
      if (this.coderow != -1 && splitedString.length-1 >= this.coderow ){
        p23.setCode(splitedString[this.coderow].trim());
      }
      if (this.xrow != -1 && splitedString.length-1 >= this.xrow ){
        try{
          p23.setX(new Double( Double.parseDouble(splitedString[this.xrow].replace(',', '.')) ));
        } catch(Exception e) {  }
      }
      if (this.yrow != -1 && splitedString.length-1 >= this.yrow){
        try{
          p23.setY(new Double( Double.parseDouble(splitedString[this.yrow].replace(',', '.')) ));
        } catch(Exception e) {  }
      }
      if (this.zrow != -1 && splitedString.length-1 >= this.zrow){
        try{
          p23.setZ(new Double( Double.parseDouble(splitedString[this.zrow].replace(',', '.')) ));
        } catch(Exception e) {  }
      }
      if (p23.is2DPoint())
        this.points.add( p23 );
    }
    return true;
  }
  
  
}

