/************************************************************************
 *                  FileConverter JAVA Coords2CSV v2.0                  *
 ************************************************************************
 * Copyright (C) 2005-07 by Michael Loesler, http://derletztekick.com   *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/
 
import java.io.*;
import java.util.*;

class Coords2CSV extends Toolbox{
  private File fileName;
  private Vector<Point23> points = null;
  private boolean zeroHight;
  private String codeAlt;
  private int resolution;
  private String seperator = null;
  private double x_add, y_add, z_add;
  //private int pktrow, coderow, xrow, yrow, zrow;
  private char commaType;

  public Coords2CSV() { }

  public Coords2CSV(File f, Vector<Point23> ps, int res, boolean zH, String cA, char cT, String sep, double x_add, double y_add, double z_add) {
    if (ps != null){
      this.fileName = f;
      this.points = ps;
      this.resolution = res;
      this.zeroHight = zH;
      this.codeAlt = cA;
      this.commaType = (cT=='.')?'.':',';
      this.seperator = (sep==null||sep.trim().equals(""))?" \t":sep;
      this.x_add = x_add;
      this.y_add = y_add;
      this.z_add = z_add;
    }
  }

  public boolean writeFile(){
    try {
      BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream( this.fileName )));
      for (int i=0; i<this.points.size(); i++){
        if (this.points.get(i).is2DPoint()){

          String line = this.points.get(i).getPKT()+this.seperator;

          if (this.points.get(i).getCode() != null)
            line += this.points.get(i).getCode()+this.seperator;
          else if (this.codeAlt != null)
            line += this.codeAlt+this.seperator;
          else
            line += this.seperator;
              
          line += this.setNumberFormat(this.points.get(i).getY()+this.y_add, 1, this.resolution, false, false).replace('.',this.commaType)+this.seperator;
          line += this.setNumberFormat(this.points.get(i).getX()+this.x_add, 1, this.resolution, false, false).replace('.',this.commaType)+this.seperator;

          if (this.points.get(i).is3DPoint())
            line += this.setNumberFormat(this.points.get(i).getZ()+this.z_add, 1, this.resolution, false, false).replace('.',this.commaType)+this.seperator;
          else if ( this.zeroHight )
            line += this.setNumberFormat(0.0, 1, this.resolution, false, false).replace('.',this.commaType)+this.seperator;
          else
            line += this.seperator;
              
          bw.write(line);
          bw.newLine();
        }
      }
      bw.close();
    }
    catch (Exception e){
      System.err.println("Fehler, datei konnte nicht erstellt werden: " + e);
      return false;
    }
    return true;
  }
}
