/************************************************************************
 *                  FileConverter JAVA Coords2DAT v2.0                  *
 ************************************************************************
 * Copyright (C) 2005-07 by Michael Loesler, http://derletztekick.com   *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/

import java.io.*;
import java.util.*;

class Coords2DAT extends Toolbox{
  private File fileName;
  private Vector<Point23> points = null;
  private boolean zeroHight;
  private String codeAlt;
  private int resolution;
  private double x_add, y_add, z_add;
  public Coords2DAT() { }
  
  public Coords2DAT(File f, Vector<Point23> ps, int res, boolean zH, String cA, double x_add, double y_add, double z_add) {
    if (ps != null){
      this.fileName = f;
      this.points = ps;
      this.zeroHight = zH;
      this.codeAlt = cA;
      this.resolution = res;
      this.x_add = x_add;
      this.y_add = y_add;
      this.z_add = z_add;
    }
  }
  
  public boolean writeFile(){
    try {
      BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream( this.fileName )));
      for (int i=0; i<this.points.size(); i++){
        if (this.points.get(i).is2DPoint()){
        
          String line  = "   "+this.align("right", ""+(i+1), 4)+" ";
          line += this.align("right", this.points.get(i).getPKT(), 12)+" ";
          
          if (this.points.get(i).getCode() != null)
            line += this.align("left", this.points.get(i).getCode(), 14);
          else if (this.codeAlt != null)
            line += this.align("left", this.codeAlt, 14);
          else
            line += this.align("left", " ", 14);

          line += " Y " + this.setNumberFormat(this.points.get(i).getY()+this.y_add, 12, this.resolution, false, false);
          line += " X " + this.setNumberFormat(this.points.get(i).getX()+this.x_add, 13, this.resolution, false, false);
          
          if (this.points.get(i).is3DPoint())
            line += " Z " + this.setNumberFormat(this.points.get(i).getZ()+this.z_add,  9, this.resolution, false, false);
          else if (this.zeroHight)
            line += " Z " + this.setNumberFormat(0.0,  9, this.resolution, false, false);
          bw.write(line);
          bw.newLine();
        }
      }
      bw.close();
    }
    catch (Exception e){
      System.err.println("Fehler, datei konnte nicht erstellt werden: " + e);
      return false;
    }
    return true;
  }
}

