/************************************************************************
 *                  FileConverter JAVA Coords2GSI v2.0                  *
 ************************************************************************
 * Copyright (C) 2005-07 by Michael Loesler, http://derletztekick.com   *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/

import java.io.*;
import java.util.*;

class Coords2GSI extends Toolbox{
  private File fileName;
  private Vector<Point23> points = null;
  private boolean zeroHight;
  private String codeAlt;
  private int resolution;
  private int GSIFormat;
  private double x_add, y_add, z_add;
  public Coords2GSI() { }
  

  public Coords2GSI(File f, Vector<Point23> ps, int res, boolean zH, String cA, int frm, double x_add, double y_add, double z_add) {
    if (ps != null){
      this.fileName = f;
      this.points = ps;
      this.zeroHight = zH;
      this.codeAlt = cA;
      this.resolution = res;
      this.GSIFormat = (frm==8||frm==16)?frm:16;
      this.x_add = x_add;
      this.y_add = y_add;
      this.z_add = z_add;
    }
  }

  public boolean writeFile(){
    try {
      Hashtable<Integer,Integer> h = new Hashtable<Integer,Integer>();
      h.put(3,0);
      h.put(4,6);
      h.put(5,8);

      BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream( this.fileName )));

      for (int i=0; i<this.points.size(); i++){
        if (this.points.get(i).is2DPoint()){
        
          String line = (this.GSIFormat==8?"":"*")+"11"+this.setNumberFormat( (double)(i+1), 4, 0, true, false);

          String dummyStr = this.setNumberFormat( 0.0, this.GSIFormat+1, 0, true, false);
          dummyStr += this.points.get(i).getPKT();
          line += "+"+dummyStr.substring(dummyStr.length()-this.GSIFormat)+" ";
          
          
          line += "81..1"+h.get(this.resolution)+this.setNumberFormat((this.points.get(i).getY()+this.y_add)*Math.pow(10,this.resolution),this.GSIFormat+1,0, true, true)+" ";
          line += "82..1"+h.get(this.resolution)+this.setNumberFormat((this.points.get(i).getX()+this.x_add)*Math.pow(10,this.resolution),this.GSIFormat+1,0, true, true)+" ";
          
          if (this.points.get(i).is3DPoint())
            line += "83..1"+h.get(this.resolution)+this.setNumberFormat((this.points.get(i).getZ()+this.z_add)*Math.pow(10,this.resolution),this.GSIFormat+1,0, true, true)+" ";
          else if(this.zeroHight)
            line += "83..1"+h.get(this.resolution)+this.setNumberFormat(0.0,this.GSIFormat+1,0, true, true)+" ";

          if (this.points.get(i).getCode() != null) {
            dummyStr = this.setNumberFormat( 0.0, this.GSIFormat+1, 0, true, false);
            dummyStr += this.points.get(i).getCode();
            line += "71....+"+dummyStr.substring(dummyStr.length()-this.GSIFormat)+" ";
          }
          else if (this.codeAlt != null) {
            dummyStr = this.setNumberFormat( 0.0, this.GSIFormat+1, 0, true, false);
            dummyStr += this.codeAlt;
            line += "71....+"+dummyStr.substring(dummyStr.length()-this.GSIFormat)+" ";
          }
          bw.write(line);
          bw.newLine();
        }
      }
      bw.close();
    }
    catch (Exception e){
      System.err.println("Fehler, datei konnte nicht erstellt werden: " + e);
      return false;
    }
    return true;
  }
}

