/************************************************************************
 *                  FileConverter JAVA Coords2M5 v2.0                   *
 ************************************************************************
 * Copyright (C) 2005-07 by Michael Loesler, http://derletztekick.com   *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/

import java.io.*;
import java.util.*;
import java.text.*;
class Coords2M5 extends Toolbox{
  private File fileName;
  private Vector<Point23> points = null;
  private boolean zeroHight;
  private String codeAlt;
  private int resolution;
  private double x_add, y_add, z_add;
  private SimpleDateFormat SDF = new SimpleDateFormat("HH:mm:ss");

  public Coords2M5() { }

  public Coords2M5(File f, Vector<Point23> ps, int res, boolean zH, String cA, double x_add, double y_add, double z_add) {
    if (ps != null){
      this.fileName = f;
      this.points = ps;
      this.resolution = res;
      this.zeroHight = zH;
      this.codeAlt = cA;
      this.x_add = x_add;
      this.y_add = y_add;
      this.z_add = z_add;
    }
  }

  public boolean writeFile(){
    try {
      BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream( this.fileName )));
      for (int i=0; i<this.points.size(); i++){
        Date dt = new Date();

        if (this.points.get(i).is2DPoint()){
          String line  = "For M5|Adr "+this.align("right", ""+(i+1), 5)+"|";
          line += "PI1 "+this.align("right", this.points.get(i).getPKT(),8);
          if (this.points.get(i).getCode()!=null)
            line += this.align("left",this.points.get(i).getCode(),5)+" "+SDF.format( dt )+"1   1|";
          else if (this.codeAlt != null)
            line += this.align("left",this.codeAlt,5)+" "+SDF.format( dt )+"1   1|";
          else
            line += this.align("left"," ",5)+" "+SDF.format( dt )+"1   1|";
          line += "Y  " + setNumberFormat(this.points.get(i).getY()+this.y_add, 14, this.resolution, false, false)+" m   |";
          line += "X  " + setNumberFormat(this.points.get(i).getX()+this.x_add, 14, this.resolution, false, false)+" m   |";
          if (this.points.get(i).is3DPoint())
            line += "Z " + setNumberFormat(this.points.get(i).getZ()+this.z_add,  14, this.resolution, false, false)+" m   |";
          else if (this.zeroHight)
            line += "Z " + setNumberFormat(0.0,  14, this.resolution, false, false)+" m   |";
          else
            line += "  " + this.align("left", " ", 14)+"|";

          bw.write(line);
          bw.newLine();
        }
      }
      bw.close();
    }
    catch (Exception e){
      System.err.println("Fehler, datei konnte nicht erstellt werden: " + e);
      return false;
    }
    return true;
  }
}

