/************************************************************************
 *                  FileConverter JAVA GSI2Coords v2.0                  *
 ************************************************************************
 * Copyright (C) 2005-07 by Michael Loesler, http://derletztekick.com   *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/

import java.io.File;
import java.util.*;

class GSI2Coords extends Toolbox {
  private File fileName;
  protected int GSIFormat;
  private Vector<Point23> points = null;
  
  public GSI2Coords () { }

  public GSI2Coords(File f){
    this(f, 16);
  }
  
  public GSI2Coords(File f, int GSIFormat){
    if (f.exists() && f.isFile() && f.canRead() && f.toString().toLowerCase().endsWith( ".gsi" ) && (GSIFormat == 8 || GSIFormat == 16)){
      this.fileName = f;
      this.GSIFormat = GSIFormat;
      this.points = new Vector<Point23>();

      if (!this.getCoords() || this.points.size() < 1)
        this.points = null;
    }
  }
  
  public Vector getPoints(){
    return this.points;
  }
  
  private double setUnit(double value, int unit){
    switch (unit) {
      case 0:
        value /= 1000;
      break;
      case 1:
        value /= (1000 * 3.28084);
      break;
      case 6:
        value /= 10000;       // 1/10 mm
      break;
      case 7:
        value /= (10000 / 3.28084);       // 1 m = 3.28084 ft
      break;
      case 8:
        value /= 100000;       // 1/100 mm
      break;
    }
    return value;
  }
  
  private boolean getCoords(){
    if (this.fileName == null)
      return false;
      
    Vector<String> v = this.readSourcefile( this.fileName );
    if (v == null)
      return false;
        
    for (int i=0; i<v.size(); i++){
      Point23 p23 = new Point23();
      String splitedLine[] = v.get(i).split("\\s+");
      for (int j=0; j<splitedLine.length; j++){
        String str = this.removeChar( splitedLine[j] );

        if ((str.length()-GSIFormat) == 7){
          if (str.substring(0,2).equals("11")){
            p23.setPKT( (removeFirstZeros(str.substring(7,str.length()))).trim()); //.replace(' ', '0') );
          }
          else if (str.substring(0,2).equals("71")){
            p23.setCode( (removeFirstZeros(str.substring(7,str.length()))).trim()); //.replace(' ', '0') );
          }
          else if (str.substring(0,2).equals("81")){
            try {
              int unit = Integer.parseInt(str.substring(5,6));
              double value = Double.parseDouble(str.substring(6,str.length()));
              p23.setY(new Double(setUnit(value, unit)));
            } catch(Exception e) {  }
          }
          else if (str.substring(0,2).equals("82")){
            try{
              int unit = Integer.parseInt(str.substring(5,6));
              double value = Double.parseDouble(str.substring(6,str.length()));
              p23.setX(new Double(setUnit(value, unit)));
            } catch(Exception e) {  }
          }
          else if (str.substring(0,2).equals("83")){
            try {
              int unit = Integer.parseInt(str.substring(5,6));
              double value = Double.parseDouble(str.substring(6,str.length()));
              p23.setZ(new Double(setUnit(value, unit)));
            } catch(Exception e) {  }
          }
        }
      }
      if (p23.is2DPoint())
        this.points.add( p23 );
    }
    return true;
  }
}


