/************************************************************************
 *                            HelpFrame v4.1                            *
 ************************************************************************
 * Copyright (C) 2005-07 by Michael Loesler, http://derletztekick.com   *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/

import java.awt.*;
import javax.swing.*;
import javax.swing.text.html.HTMLEditorKit;
import java.awt.event.*;
import javax.swing.event.*;
import java.util.*;
import java.io.*;

class HelpFile {
  public String Filename = null;
  public String FileURI = null;
  public HelpFile() {  }
  public HelpFile(String N, String F) {
     this.Filename = N;
     this.FileURI = F;
  }
}

public class HelpFrame extends JFrame {
  // Anfang Variablen

  JScrollPane HelpjScrollPane = new JScrollPane();
  JScrollPane MenuejScrollPane = new JScrollPane();
  JTextPane HelpjTextPane = new JTextPane();

  JButton SearchjButton = new JButton();
  JButton ListofContentjButton = new JButton();
  JTextField KeywordsjTextField = new JTextField();
  JList MenuejList = new JList();

  String helpdesc[] = null;
  Vector<HelpFile> HF = null;
  Vector<String> HFContent = null;

  // Ende Variablen

  public HelpFrame(String title, String Icon, Vector<HelpFile> HF, int frameWidth, int frameHeight, int pos_x, int pos_y, int firstindex) {
    // Frame-Initialisierung
    super(title);


    Container cp = getContentPane();
    frameHeight = frameHeight >= 250?frameHeight:250;
    frameWidth = frameWidth >= 350?frameWidth:350;
    try {
      ImageIcon HelpFrameIcon = new ImageIcon(getClass().getResource(Icon));
      this.setIconImage(HelpFrameIcon.getImage());
    }
    catch ( Exception e ) { };

    this.setSize(frameWidth, frameHeight);
    this.setLocation(pos_x, pos_y);
    this.setResizable(false);
    cp.setLayout(null);

    // Anfang Komponenten

    helpdesc = new String[HF.size()];
    this.HF = HF;
    this.HFContent = new Vector();
    if (firstindex > (HF.size()-1))
      firstindex = 0;
    
    for (int i=0; i<HF.size(); i++)
      helpdesc[i] = HF.get(i).Filename;

    HelpjScrollPane.setBounds(new Rectangle(170, 15, (frameWidth-190), (frameHeight-55)));
    HelpjTextPane.setText("");
    HelpjTextPane.setEditorKit(new HTMLEditorKit());
    HelpjTextPane.setEditable(false);

    try {
      HelpjTextPane.setPage(getClass().getResource(HF.get(firstindex).FileURI));
    }
    catch (Exception e) {
      JOptionPane.showMessageDialog(null,"Fehler beim Laden der Hilfedatei "+e.getMessage()+"!" , "Fehler", JOptionPane.ERROR_MESSAGE);
      return;
    }
    HelpjTextPane.addHyperlinkListener(new HyperlinkListener() {
      public void hyperlinkUpdate(HyperlinkEvent h) {
        if (h.getEventType() == HyperlinkEvent.EventType.ACTIVATED) {
          String url = h.getDescription();
          if ((url.substring(0,7).equals("http://")) || (url.substring(0,7).equals("mailto:"))) {
            try { BrowserLauncher.openURL(url); } catch (Exception e) {}
          }
          else {
            try { HelpjTextPane.setPage(h.getURL()); } catch (Exception e) {}
          }
        }
      }
    });

    HelpjScrollPane.getViewport().add(HelpjTextPane);

    KeywordsjTextField.setToolTipText("Suchbegriff");
    KeywordsjTextField.setBounds(new Rectangle(10, 20, 150, 20));
    KeywordsjTextField.addKeyListener(new KeyAdapter() {
      public void keyPressed(KeyEvent evt) {
        KeywordsjTextFieldKeyPressed(evt);
      }
    });
    
    SearchjButton.setToolTipText("Suche starten");
    SearchjButton.setBounds(new Rectangle(10, 50, 150, 20));
    SearchjButton.setText("Suche");

    MenuejList = new JList(helpdesc);
    MenuejList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
    MenuejList.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent evt) {
        MenuejListMouseClicked(evt);
      }
    });

    MenuejScrollPane.getViewport().add(MenuejList);
    MenuejScrollPane.setBounds(new Rectangle(10, 100, 150, frameHeight-200));

    ListofContentjButton.setToolTipText("Inhalt");
    ListofContentjButton.setBounds(new Rectangle(10, frameHeight-90, 150, 20));
    ListofContentjButton.setText("Inhaltsverzeichnis");

    cp.add(MenuejScrollPane);
    cp.add(KeywordsjTextField);
    cp.add(SearchjButton);
    cp.add(HelpjScrollPane);
    cp.add(ListofContentjButton);

    SearchjButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent evt) {
        SearchjButtonActionPerformed(evt);
      }
    });

    ListofContentjButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent evt) {
        ListofContentjButtonActionPerformed(evt);
      }
    });

    // Ende Komponenten
    setVisible(true);
  }

  // Anfang Ereignisprozeduren
  private void startsearching() {
    if (KeywordsjTextField.getText().trim().length() > 0){
      searchEngine searchValue = null;
      boolean searchingAgain = HFContent == null || this.HFContent.size() == 0?false:true;
      Vector<String> searchresult = new Vector();
      for (int i=0; i<HF.size(); i++){

        if (!searchingAgain){
          searchValue = new searchEngine(new File(HF.get(i).FileURI), KeywordsjTextField.getText());
          HFContent.add( searchValue.getContent()  );
        }
        else {
          searchValue = new searchEngine(HFContent.get(i), KeywordsjTextField.getText());
        }

        if (searchValue.getResult()){
          searchresult.add(HF.get(i).Filename);
        }
      }
      if (searchresult.size()>0){
        MenuejList.setListData( (String[])searchresult.toArray( new String[(searchresult.size())]) );
      }
      else {
        JOptionPane.showMessageDialog(null,"Die Suchanfrage ergab keine bereinstimmung!" , "Hinweis", JOptionPane.INFORMATION_MESSAGE);
        MenuejList.setListData( helpdesc );
      }
    }
  }
  
  private void SearchjButtonActionPerformed(ActionEvent evt) {
    if (evt.getSource() == SearchjButton){
      startsearching();
    }
  }

  private void KeywordsjTextFieldKeyPressed(KeyEvent evt) {
    if (evt.getKeyCode() == KeyEvent.VK_ENTER) {
      startsearching();
    }
  }
  
  private void ListofContentjButtonActionPerformed(ActionEvent evt) {
    if (evt.getSource() == ListofContentjButton){
      MenuejList.setListData( helpdesc );
    }
  }

  private void MenuejListMouseClicked(MouseEvent evt) {
    if (evt.getSource() == MenuejList){
      try {
        for (int i=0; i<helpdesc.length; i++){
          if (MenuejList.getSelectedValue().toString().equalsIgnoreCase(helpdesc[i])){
            HelpjTextPane.setPage(getClass().getResource(HF.get(i).FileURI));
            break;
          }
        }
      }
      catch (Exception e) {
        JOptionPane.showMessageDialog(null,"Fehler beim Laden der Hilfedatei "+e.getMessage()+"!" , "Fehler", JOptionPane.ERROR_MESSAGE);
      }
    }
  }
  // Ende Ereignisprozeduren
}
