/************************************************************************
 *                        LanguageChooser v1.3                          *
 ************************************************************************
 * Copyright (C) 2007 by Michael Loesler, http://derletztekick.com      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/
 
import java.io.*;
import java.util.*;

class LangFileFilter implements FilenameFilter{
  public boolean accept( File f, String s ) {
    return s.toLowerCase().endsWith( ".lng" );
  }
}

public class LanguageChooser {
  private File defaultFile = null;
  protected boolean isReady = false;
  private Hashtable<String, Hashtable<Integer, String>> ht = new Hashtable<String, Hashtable<Integer, String>>();

  public LanguageChooser() { }
  
  public LanguageChooser(String dF) {
    this(new File(dF));
  }
  
  public LanguageChooser(String dF, boolean langFromDIR) {
    this(new File(dF), langFromDIR);
  }
  
  public LanguageChooser(File dF) {
    this.defaultFile = dF;
    boolean langFromDIR = isLangFileInDir();
    this.isReady = readLangFile( langFromDIR );
    if (!langFromDIR)
      this.writeLangFile();
  }
  
  public LanguageChooser(File dF, boolean langFromDIR) {
    this.defaultFile = dF;
    this.isReady = readLangFile( langFromDIR );
  }
  
  public String getEntry(String cat, int index){
    Hashtable<Integer, String> h = this.getCategory( cat );
    index = Math.abs(index);
    if (h == null || !h.containsKey(index))
      return null;
    return h.get(index);
  }
  
  public Hashtable<Integer, String> getCategory(String cat){
    return ht.get( cat );
  }
  
  private boolean isLangFileInDir() {
    File[] files = new File( "." ).listFiles( new LangFileFilter() );
    if (files.length > 0 && files[0].isFile() && files[0].canRead()){
      this.defaultFile = files[0];
      return true;
    }
    return false;
  }

  public boolean writeLangFile() {
    if (!this.isReady)
      return false;
    try {
      BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream( "naive.lng" )));
      //bw.write( "[Languagefile]\r\n0="+this.defaultFile.getName()+"\r\n" );
      for ( Map.Entry<String, Hashtable<Integer, String>> entry: this.ht.entrySet() ) {
        bw.write( "\r\n\r\n["+entry.getKey()+"]\r\n" );
        Hashtable<Integer, String> items = this.ht.get(entry.getKey());
        //for (int i=0; i<entry.getValue().size(); i++)
        for ( Map.Entry<Integer, String> item: items.entrySet() )
          bw.write( item.getKey()+"="+item.getValue() +"\r\n"); //bw.write( item.getKey()+"="+entry.getValue().get(i) +"\r\n");
      }
      bw.close();
    }
    catch (Exception e) {
      System.err.println(e);
      return false;
    }
    return true;
  }

  private boolean readLangFile(boolean inDIR){
    try {
      InputStream is = null;
      if (inDIR)
        is = new FileInputStream( this.defaultFile );
      else
        is = this.getClass().getResourceAsStream("/lang/"+this.defaultFile.toString());

      BufferedReader br = new BufferedReader(new InputStreamReader(is));

      String line;
      String category = null;
      Hashtable<Integer, String> entries = new Hashtable<Integer, String>();
      while ((line = br.readLine()) != null) {
        if (line.trim().length() != 0) {
          if (line.matches("\\[(.+?)\\]")) {
            if (category != null && category.length() > 0 && !this.ht.containsKey(category) && entries.size() > 0) {
              this.ht.put(category, entries);
              entries = new Hashtable<Integer, String>();
            }
            category = line.replaceAll("\\[(.+?)\\]", "$1");
          }
          
          else if (line.matches("^([0-9]+)=(.+)")) {
            entries.put(Integer.parseInt(line.replaceAll("^([0-9]+)=(.+)", "$1")), line.replaceAll("^([0-9]+)=(.+)", "$2"));
          }
        }
      }
      if (category != null && category.length() > 0 && !this.ht.containsKey(category) && entries.size() > 0) {
        this.ht.put(category, entries);
      }
      br.close();
    }
    catch (Exception e) {
      System.err.println("File not found! "+e);
      return false;
    }
    if (this.ht.size() > 0)
      return true;
    return false;
  }
  
}

