/************************************************************************
 *                  FileConverter JAVA M52Coords v2.0                   *
 ************************************************************************
 * Copyright (C) 2005-07 by Michael Loesler, http://derletztekick.com   *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/

import java.util.*;
import java.io.File;

class M52Coords extends Toolbox {
  private File fileName;
  private Vector<Point23> points = null;
  protected String Format = "m5";


  public M52Coords() { }
  
  public M52Coords (File f) {
    if (f.exists() && f.isFile() && f.canRead() && (f.toString().toLowerCase().endsWith( ".dat" ) || f.toString().toLowerCase().endsWith( ".rec" ) || f.toString().toLowerCase().endsWith( ".m5" ))){
      this.fileName = f;
      this.points = new Vector<Point23>();
      if (!this.getCoords() || this.points.size() < 1)
        this.points = null;
    }
  }
  
  public Vector getPoints(){
    return this.points;
  }

  private double setMeter(String unit, double value){
    if (unit.trim().equalsIgnoreCase("ft"))      //1 m = 3.28084 ft
      return value/3.28084;
    else
      return value;
  }
  
  private boolean getCoords(){
    if (this.fileName == null)
      return false;

    Vector<String> v = this.readSourcefile( this.fileName );
    if (v == null)
      return false;

    for (int i=0; i<v.size(); i++){
      Point23 p23 = new Point23();
      if (v.get(i).length()>=6 && v.get(i).substring(3,6).trim().equalsIgnoreCase(Format)){
        if (v.get(i).length()>=48){
          p23.setPKT((v.get(i).substring(21,29)).trim());
          p23.setCode((v.get(i).substring(29,34)).trim());
        }

        // 1. Werteblock
        if (v.get(i).length()>=72 && v.get(i).substring(49,51).trim().equalsIgnoreCase("y") ){
          try{
            p23.setY(new Double(setMeter(v.get(i).substring(67,71), Double.parseDouble(v.get(i).substring(52,66)) )));
          } catch(Exception e) {  }
        }
        else if (v.get(i).length()>=72 && v.get(i).substring(49,51).trim().equalsIgnoreCase("x") ){
          try{
            double value = Double.parseDouble(v.get(i).substring(52,66));
            p23.setX(new Double(setMeter(v.get(i).substring(67,71),Double.parseDouble(v.get(i).substring(52,66)) )));
          } catch(Exception e) {  }
        }
        else if (v.get(i).length()>=72 && v.get(i).substring(49,51).trim().equalsIgnoreCase("z") ){
          try{
            p23.setZ(new Double(setMeter(v.get(i).substring(67,71), Double.parseDouble(v.get(i).substring(52,66)) )));
          } catch(Exception e) {  }
        }

        // 2. Werteblock
        if (v.get(i).length()>=95 && v.get(i).substring(72,74).trim().equalsIgnoreCase("x") ){
          try{
            p23.setX(new Double(setMeter(v.get(i).substring(90,94), Double.parseDouble(v.get(i).substring(75,89)) )));
          } catch(Exception e) {  }
        }
        else if (v.get(i).length()>=95 && v.get(i).substring(72,74).trim().equalsIgnoreCase("y") ){
          try{
            p23.setY(new Double(setMeter(v.get(i).substring(90,94), Double.parseDouble(v.get(i).substring(75,89)) )));
          } catch(Exception e) {  }
        }
        else if (v.get(i).length()>=95 && v.get(i).substring(72,74).trim().equalsIgnoreCase("z") ){
          try{
            p23.setZ(new Double(setMeter(v.get(i).substring(90,94), Double.parseDouble(v.get(i).substring(75,89)) )));
          } catch(Exception e) {  }
        }

        // 3.Werteblock
        if (v.get(i).length()>=117 && v.get(i).substring(95,97).trim().equalsIgnoreCase("z") ){
          try{
            p23.setZ(new Double(setMeter(v.get(i).substring(113,117), Double.parseDouble(v.get(i).substring(98,112)) )));
          } catch(Exception e) {  }
        }
        else if (v.get(i).length()>=117 && v.get(i).substring(95,97).trim().equalsIgnoreCase("x") ){
          try{
            p23.setX(new Double(setMeter(v.get(i).substring(113,117), Double.parseDouble(v.get(i).substring(98,112)) )));
          } catch(Exception e) {  }
        }
        else if (v.get(i).length()>=117 && v.get(i).substring(95,97).trim().equalsIgnoreCase("y") ){
          try{
            p23.setY(new Double(setMeter(v.get(i).substring(113,117), Double.parseDouble(v.get(i).substring(98,112)) )));
          } catch(Exception e) {  }
        }

        if (p23.is2DPoint())
          this.points.add( p23 );

      }
    }
    return true;
  }
  
  
}

