/************************************************************************
 *                  FileConverter JAVA MainMenu v1.1                    *
 ************************************************************************
 * Copyright (C) 2007 by Michael Loesler, http://derletztekick.com      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/
 
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
public class MainMenu extends JMenuBar{
  private JMenu fileMenu = new JMenu();
  private JMenu settingsMenu = new JMenu();
  private JMenu helpMenu = new JMenu();
  private JMenu langMenu = new JMenu();
  private JMenu tabMenu = new JMenu();
  
  public JMenuItem openMenu = new JMenuItem();
  public JMenuItem saveMenu = new JMenuItem();
  public JMenuItem closeMenu = new JMenuItem();
  
  private JRadioButtonMenuItem deLangMenu = new JRadioButtonMenuItem();
  private JRadioButtonMenuItem enLangMenu = new JRadioButtonMenuItem();
  private ButtonGroup langBG = new ButtonGroup();
  
  private JMenuItem tabFormatMenu = new JMenuItem();
  private JMenuItem tabGlobalSettingMenu = new JMenuItem();

  public JMenuItem helpAndInfoMenu = new JMenuItem();

  private LanguageChooser lc = null;
  public JTabbedPane ToolsjTabbedPane = null;

  public FileConverter p = null;
  public MainMenu(FileConverter parent) {
    this.p = parent;
    this.lc = parent.lc;


    //Hauptmenueintraege
    this.fileMenu = this.addMnemonic( this.lc.getEntry("Menu", 0));
    this.settingsMenu = this.addMnemonic( this.lc.getEntry("Menu", 1));
    this.helpMenu = this.addMnemonic( this.lc.getEntry("Menu", 2));
    this.add( fileMenu );
    this.add( settingsMenu );
    this.add( helpMenu );
    

    openMenu = this.addMenuItem( this.lc.getEntry("File", 0), 'O' );
    saveMenu = this.addMenuItem( this.lc.getEntry("File", 1), 'K' );
    closeMenu = this.addMenuItem( this.lc.getEntry("File", 2), 'E' );
    fileMenu.add( openMenu );
    fileMenu.add( saveMenu );
    fileMenu.addSeparator();
    fileMenu.add( closeMenu );
    
    
    //Einstellungen
    langMenu = this.addMnemonic( this.lc.getEntry("Settings", 0));
    tabFormatMenu = this.addMenuItem( this.lc.getEntry("Settings", 1), 'M' );
    tabGlobalSettingMenu = this.addMenuItem( this.lc.getEntry("Settings", 2), 'G' );

    langBG.add( deLangMenu );
    langBG.add( enLangMenu );

    deLangMenu.setText( this.lc.getEntry("Lang", 0) );
    enLangMenu.setText( this.lc.getEntry("Lang", 1) );
    try {
      deLangMenu.setSelected( this.lc.getEntry("Languagefile", 0).equalsIgnoreCase("de.lng") );
      enLangMenu.setSelected( this.lc.getEntry("Languagefile", 0).equalsIgnoreCase("en.lng") );
    }catch (Exception e) { }

    
    settingsMenu.add(langMenu);
    settingsMenu.add(tabFormatMenu);
    settingsMenu.add(tabGlobalSettingMenu);
    langMenu.add(deLangMenu);
    langMenu.add(enLangMenu);

    //Hilfe
    helpAndInfoMenu.setText( this.lc.getEntry("Help", 0));
    helpMenu.add(helpAndInfoMenu);
    
    tabGlobalSettingMenu.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent evt) {
        changeTabActionPerformed(evt);
      }
    });
    
    tabFormatMenu.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent evt) {
        changeTabActionPerformed(evt);
      }
    });

    helpAndInfoMenu.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent evt) {
        HelpJBActionPerformed(evt);
      }
    });
    
    openMenu.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent evt) {
        p.openDialogActionPerformed(evt);
      }
    });
    
    saveMenu.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent evt) {
        p.convertData(evt);
      }
    });
    
    closeMenu.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent evt) {
        p.exitTool();
      }
    });

    deLangMenu.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent evt) {
        selectLang(evt);
      }
    });

    enLangMenu.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent evt) {
        selectLang(evt);
      }
    });
  }

  public void HelpJBActionPerformed(ActionEvent evt) {
    p.HelpjButtonActionPerformed(evt);
  }
  
  private void changeTabActionPerformed(ActionEvent evt){
    if (evt.getSource() == tabGlobalSettingMenu)
      p.ToolsjTabbedPane.setSelectedIndex(1);
    else
      p.ToolsjTabbedPane.setSelectedIndex(0);
  }

  private void selectLang(ActionEvent evt) {
    boolean hasChanged = false;
    String errHead = this.lc.getEntry("Message", 0);
    String errMsg = this.lc.getEntry("Message", 9);
    String infoHead = this.lc.getEntry("Message", 7);
    String infoMsg = this.lc.getEntry("Message", 8);
    LanguageChooser tmpLC = null;
    if (evt.getSource() == enLangMenu){
      if (!this.lc.getEntry("Languagefile", 0).equals("en.lng")){
        tmpLC  = new LanguageChooser("en.lng",false);
        hasChanged = tmpLC.writeLangFile();
      }
      else
        return;
    }
    else if (evt.getSource() == deLangMenu){
      if (!this.lc.getEntry("Languagefile", 0).equals("de.lng")){
        tmpLC = new LanguageChooser("de.lng",false);
        hasChanged = tmpLC.writeLangFile();
      }
      else
        return;
    }

    if (hasChanged && this.lc.isReady){
      this.lc = tmpLC;
      if (JOptionPane.showOptionDialog(null, infoMsg, infoHead, JOptionPane.YES_NO_OPTION, JOptionPane.QUESTION_MESSAGE,null,null,null) == JOptionPane.YES_OPTION){
        p.setVisible(false);
        p.dispose();
        new FileConverter(p.getTitle(), "fc_icon.png", p.getWidth(), p.getHeight() ,null);
      }
    }
    else
      JOptionPane.showMessageDialog(null, errMsg, errHead ,JOptionPane.ERROR_MESSAGE);

  }
  
  private JMenu addMnemonic(String s){
    if ( s.indexOf("_") > -1 ){
      int pos = s.indexOf("_");
      char c = s.charAt( pos+1 );
      StringBuffer sb = new StringBuffer(s).delete(pos,pos+1);
      JMenu m = new JMenu( sb.toString() );
      m.setMnemonic( c );
      return m;
    }
    else
      return new JMenu( s );
  }
  
  private JMenuItem processMnemonic( String s ) {
    if ( s.indexOf("_") > -1 ) {
      int pos = s.indexOf("_");
      char c = s.charAt( pos+1 );
      StringBuffer sb = new StringBuffer(s).delete(pos,pos+1);
      return new JMenuItem( sb.toString(), c );
    }
    else
      return new JMenuItem( s );
  }
  
  private JMenuItem addMenuItem( String s, char keyChar) {
    JMenuItem menuItem = processMnemonic( s );
    if ( keyChar != 0 )
      menuItem.setAccelerator( KeyStroke.getKeyStroke(keyChar, InputEvent.CTRL_MASK) );
    return menuItem;
  }

  private JMenuItem  addMenuItem( String s ) {
    return addMenuItem( s, (char)0 );
  }

  
}

