/************************************************************************
 *                FileConverter JAVA MyFileFilter v1.1                  *
 ************************************************************************
 * Copyright (C) 2005-07 by Michael Loesler, http://derletztekick.com   *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/

import java.io.File;
import javax.swing.filechooser.FileFilter;

public class MyFileFilter extends FileFilter {
    private String ext;
    private String desc;

    private boolean acceptDirs = true;

    public MyFileFilter(String ext) {
        this.ext = ext;
        this.desc = ext + "-Files (" + generateExtensionString(ext) + ")";
    }

    public MyFileFilter(String ext, String desc) {
        this.ext = ext;
        this.desc = desc + " (" + generateExtensionString(ext) + ")";
    }

    public String getDescription() {
        return desc;
    }

    public boolean accept(File f) {
        if (f.isDirectory() && acceptDirs) {
            return true;
        }
        if (!isMultiExtensionString(ext)) {
            return f.getName().toLowerCase().endsWith(ext);
        }
        String[] exts = ext.split(",");
        for (int i = 0; i < exts.length; i++) {
            if (f.getName().toLowerCase().endsWith(exts[i].trim())) {
                return true;
            }
        }
        return false;
    }

    protected boolean isMultiExtensionString(String ext) {
        return ext.indexOf(',') >= 0;
    }

    protected String generateExtensionString(String ext) {
        String[] exts = ext.split(",");
        StringBuffer sb = new StringBuffer();
        for (int i = 0; i < exts.length; i++) {
            sb.append("*.");
            sb.append(exts[i].trim());
            if (i != exts.length - 1) {
                sb.append(",");
            }
        }
        return sb.toString();
    }
}
