/************************************************************************
 *                  FileConverter JAVA PKT2Coords v2.0                  *
 ************************************************************************
 * Copyright (C) 2005-07 by Michael Loesler, http://derletztekick.com   *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the                        *
 * Free Software Foundation, Inc.,                                      *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
 ************************************************************************/
 
import java.util.*;
import java.io.File;

class PKT2Coords extends Toolbox {
  private File fileName;
  private Vector<Point23> points = null;
  
  public PKT2Coords () { }
  
  public PKT2Coords(File f){
    if (f.exists() && f.isFile() && f.canRead() && f.toString().toLowerCase().endsWith( ".pkt" )){
      this.fileName = f;
      this.points = new Vector<Point23>();
      if (!this.getCoords() || this.points.size() < 1)
        this.points = null;
    }
  }

  public Vector getPoints(){
    return this.points;
  }

  private boolean getCoords(){
    if (this.fileName == null)
      return false;

    Vector<String> v = this.readSourcefile( this.fileName );
    if (v == null)
      return false;

    for (int i=0; i<v.size(); i++){
      Point23 p23 = new Point23();
      String splitedString[] = v.get(i).trim().split( "\\s+" );
      if (splitedString.length >= 4){
        p23.setPKT( splitedString[0].trim() );
        p23.setCode( splitedString[1].trim() );

        try{
          p23.setY(new Double( Double.parseDouble(splitedString[2].replace(',', '.')) ));
        } catch(Exception e) {  }

        try{
          p23.setX(new Double( Double.parseDouble(splitedString[3].replace(',', '.')) ));
        } catch(Exception e) {  }

        if (splitedString.length > 4){
          try{
            p23.setZ(new Double( Double.parseDouble(splitedString[4].replace(',', '.')) ));
          } catch(Exception e) {  }
        }
        if (p23.is2DPoint())
          this.points.add( p23 );
      }
    }
    return true;
  }

}

